==> owlapi-parsers-3.4.2-sources.jar: org/coode/owlapi/obo/renderer/OBORelationship.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.coode.owlapi.obo.renderer;

import org.semanticweb.owlapi.model.OWLClass;
import org.semanticweb.owlapi.model.OWLEntity;
import org.semanticweb.owlapi.model.OWLNamedIndividual;
import org.semanticweb.owlapi.model.OWLObjectProperty;

/**
 * Author: Nick Drummond<br>
 * The University Of Manchester<br>
 * Bio Health Informatics Group<br>
 * Date: Dec 18, 2008<br><br>
 */
@SuppressWarnings("javadoc")
public class OBORelationship {

    private OWLObjectProperty property;

    private int minCardinality = -1;
    private int maxCardinality = -1;
    private int cardinality = -1;

    private OWLEntity filler;

    public OBORelationship(OWLObjectProperty property, OWLNamedIndividual filler) {
        this.property = property;
        this.filler = filler;
    }

    public OBORelationship(OWLObjectProperty property, OWLClass filler) {
        this.property = property;
        this.filler = filler;
    }

    public OWLObjectProperty getProperty() {
        return property;
    }


    public int getMinCardinality() {
        return minCardinality;
    }


    public OWLEntity getFiller() {
        return filler;
    }


    public int getMaxCardinality() {
        return maxCardinality;
    }


    public void setMaxCardinality(int maxCardinality) {
        this.maxCardinality = maxCardinality;
    }


    public void setMinCardinality(int minCardinality) {
        this.minCardinality = minCardinality;
    }


    public int getCardinality() {
        return cardinality;
    }


    public void setCardinality(int cardinality) {
        this.cardinality = cardinality;
    }
}

==> owlapi-parsers-3.5.1-sources.jar: org/coode/owlapi/obo/renderer/OBORelationship.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.coode.owlapi.obo.renderer;

import org.semanticweb.owlapi.model.OWLClass;
import org.semanticweb.owlapi.model.OWLEntity;
import org.semanticweb.owlapi.model.OWLNamedIndividual;
import org.semanticweb.owlapi.model.OWLObjectProperty;

/**
 * @author Nick Drummond, The University Of Manchester, Bio Health Informatics
 *         Group, Date: Dec 18, 2008
 */
public class OBORelationship {

    private OWLObjectProperty property;
    private int minCardinality = -1;
    private int maxCardinality = -1;
    private int cardinality = -1;
    private OWLEntity filler;

    /**
     * @param property
     *        property
     * @param filler
     *        filler
     */
    public OBORelationship(OWLObjectProperty property, OWLNamedIndividual filler) {
        this.property = property;
        this.filler = filler;
    }

    /**
     * @param property
     *        property
     * @param filler
     *        filler
     */
    public OBORelationship(OWLObjectProperty property, OWLClass filler) {
        this.property = property;
        this.filler = filler;
    }

    /** @return property */
    public OWLObjectProperty getProperty() {
        return property;
    }

    /** @return min cardinality */
    public int getMinCardinality() {
        return minCardinality;
    }

    /** @return filler */
    public OWLEntity getFiller() {
        return filler;
    }

    /** @return max cardinality */
    public int getMaxCardinality() {
        return maxCardinality;
    }

    /**
     * @param maxCardinality
     *        maxCardinality
     */
    public void setMaxCardinality(int maxCardinality) {
        this.maxCardinality = maxCardinality;
    }

    /**
     * @param minCardinality
     *        minCardinality
     */
    public void setMinCardinality(int minCardinality) {
        this.minCardinality = minCardinality;
    }

    /** @return get crdinality */
    public int getCardinality() {
        return cardinality;
    }

    /**
     * @param cardinality
     *        cardinality
     */
    public void setCardinality(int cardinality) {
        this.cardinality = cardinality;
    }
}
